@@ -42,8 +42,8 @@ sub validate_env {
     unless (defined($env->{PATH_INFO})) { # allows empty string
         die('Missing mandatory env param: PATH_INFO');
     }
-    if ($env->{PATH_INFO} !~ m!^/!) {
-        die('PATH_INFO must begin with / ($env->{SCRIPT_NAME})');
+    if ($env->{PATH_INFO} ne '' && $env->{PATH_INFO} !~ m!^/!) {
+        die('PATH_INFO must begin with / ($env->{PATH_INFO})');
     }
     unless (defined($env->{SERVER_NAME})) {
         die('Missing mandatory env param: SERVER_NAME');
